==> akismet-0.3.2.tar.gz: lib/src/core/comment.dart <==
/**
 * Implementation of the `akismet.core.Comment` class.
 * @module core.comment
 */
part of akismet.core;

/**
 * Represents a comment submitted by an author.
 * @class akismet.core.Comment
 * @constructor
 * @param {String} [content] The comment's content.
 * @param {akismet.core.Author} [author] The comment's author.
 */
class Comment {

  Comment([ this.content, this.author ]);

  /**
   * Creates a new instance from the specified map in JSON format.
   * @method fromJson
   * @param {Map&lt;String, String&gt;} map A map in JSON format specifying the object properties.
   * @return {akismet.core.Author} The author corresponding to the specified map.
   * @static
   */
  Comment.fromJson(Map<String, String> map) {
    assert(map!=null);

    if(map.keys.any((key) => key.startsWith('comment_author') || key.startsWith('user'))) author=new Author.fromJson(map);
    if(map['comment_content']!=null) content=map['comment_content'];
    if(map['comment_type']!=null) type=map['comment_type'];
    if(map['permalink']!=null) permalink=Uri.parse(map['permalink']);
    if(map['referrer']!=null) referrer=Uri.parse(map['referrer']);
  }

  /**
   * The comment's author.
   * @property author
   * @type akismet.core.Author
   */
  Author author;

  /**
   * The comment's content.
   * @property content
   * @type String
   */
  String content;

  /**
   * The permanent location of the entry the comment is submitted to.
   * @property permalink
   * @type Uri
   */
  Uri permalink;

  /**
   * The URL of the webpage that linked to the entry being requested.
   * @property referrer
   * @type Uri
   */
  Uri referrer;

  /**
   * The comment's type.
   * This string value specifies a `akismet.core.CommentType` constant or a made up value like `"registration"`.
   * @property type
   * @type String
   */
  String type;

  /**
   * Converts this object to a map in JSON format.
   * @method toJson
   * @return {Map&lt;String, String&gt;} The map in JSON format corresponding to this object.
   */
  Map<String, String> toJson() {
    var map={};

    if(author!=null) map.addAll(author.toJson());
    if(content!=null) map['comment_content']=content;
    if(type!=null) map['comment_type']=type;
    if(permalink!=null) map['permalink']=permalink.toString();
    if(referrer!=null) map['referrer']=referrer.toString();

    return map;
  }

  /**
   * Returns a string representation of this object.
   * @method toString
   * @return {String} A string that represents the current object.
   */
  @override
  String toString() => 'Comment ${toJson()}';
}

/**
 * Specifies the type of a comment.
 * @class akismet.core.CommentType
 * @static
 */
abstract class CommentType {

  /**
   * A standard comment.
   * @property COMMENT
   * @type String
   * @static
   * @default
   */
  static const String COMMENT='comment';

  /**
   * A [pingback](https://en.wikipedia.org/wiki/Pingback) comment.
   * @property PINGBACK
   * @type String
   * @static
   * @final
   */
  static const String PINGBACK='pingback';

  /**
   * A [trackback](https://en.wikipedia.org/wiki/Trackback) comment.
   * @property TRACKBACK
   * @type String
   * @static
   * @final
   */
  static const String TRACKBACK='trackback';
}

==> akismet-0.6.1.tar.gz: lib/src/core/comment.dart <==
/**
 * Implementation of the `akismet.Comment` class.
 * @module core.comment
 */
part of akismet.core;

/**
 * Represents a comment submitted by an author.
 * @class akismet.Comment
 * @constructor
 * @param {String} [content] The comment's content.
 * @param {akismet.Author} [author] The comment's author.
 */
class Comment {

  Comment([ this.content, this.author ]);

  /**
   * Creates a new instance from the specified map in JSON format.
   * @method fromJson
   * @param {Map&lt;String, String&gt;} map A map in JSON format specifying the object properties.
   * @return {akismet.Comment} The author corresponding to the specified map.
   * @static
   */
  Comment.fromJson(Map<String, String> map) {
    assert(map!=null);

    if(map.keys.any((key) => key.startsWith('comment_author') || key.startsWith('user'))) author=new Author.fromJson(map);
    if(map['comment_content']!=null) content=map['comment_content'];
    if(map['comment_date_gmt']!=null) date=DateTime.parse(map['comment_date_gmt']);
    if(map['comment_post_modified_gmt']!=null) postModified=DateTime.parse(map['comment_post_modified_gmt']);
    if(map['comment_type']!=null) type=map['comment_type'];
    if(map['permalink']!=null) permalink=Uri.parse(map['permalink']);
    if(map['referrer']!=null) referrer=Uri.parse(map['referrer']);
  }

  /**
   * The comment's author.
   * @property author
   * @type akismet.Author
   */
  Author author;

  /**
   * The comment's content.
   * @property content
   * @type String
   */
  String content;

  /**
   * The UTC timestamp of the creation of the comment.
   * @property date
   * @type DateTime
   */
  DateTime date;

  /**
   * The permanent location of the entry the comment is submitted to.
   * @property permalink
   * @type Uri
   */
  Uri permalink;

  /**
   * The UTC timestamp of the publication time for the post, page or thread on which the comment was posted.
   * @property postModified
   * @type DateTime
   */
  DateTime postModified;

  /**
   * The URL of the webpage that linked to the entry being requested.
   * @property referrer
   * @type Uri
   */
  Uri referrer;

  /**
   * The comment's type.
   * This string value specifies a `akismet.CommentType` constant or a made up value like `"registration"`.
   * @property type
   * @type String
   */
  String type;

  /**
   * Converts this object to a map in JSON format.
   * @method toJson
   * @return {Map&lt;String, String&gt;} The map in JSON format corresponding to this object.
   */
  Map<String, String> toJson() {
    var map={};

    if(author!=null) map.addAll(author.toJson());
    if(content!=null) map['comment_content']=content;
    if(date!=null) map['comment_date_gmt']=date.toIso8601String();
    if(postModified!=null) map['comment_post_modified_gmt']=postModified.toIso8601String();
    if(type!=null) map['comment_type']=type;
    if(permalink!=null) map['permalink']=permalink.toString();
    if(referrer!=null) map['referrer']=referrer.toString();

    return map;
  }

  /**
   * Returns a string representation of this object.
   * @method toString
   * @return {String} A string that represents the current object.
   */
  @override
  String toString() => 'Comment ${JSON.encode(this)}';
}

/**
 * Specifies the type of a comment.
 * @class akismet.CommentType
 * @static
 */
abstract class CommentType {

  /**
   * A standard comment.
   * @property COMMENT
   * @type String
   * @static
   * @final
   */
  static const String COMMENT='comment';

  /**
   * A [pingback](https://en.wikipedia.org/wiki/Pingback) comment.
   * @property PINGBACK
   * @type String
   * @static
   * @final
   */
  static const String PINGBACK='pingback';

  /**
   * A [trackback](https://en.wikipedia.org/wiki/Trackback) comment.
   * @property TRACKBACK
   * @type String
   * @static
   * @final
   */
  static const String TRACKBACK='trackback';
}
